# vim: set ts=4 sw=4 et:
# Copyright (c) 2005-2010 oc2pus, 2011 Pascal Bleser
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments to packman@links2linux.de
%define _lto_cflags %{nil}
%define ruby_sitedir %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitelibdir"]')

%{!?python3_sitelib:  %global python3_sitelib  %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python3_sitearch: %global python3_sitearch %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

Name:           ecasound
Version:        2.9.3
Release:        1699.1.pm.60
Summary:        Multitrack audio processing tool
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://ecasound.seul.org/
Source:         ecasound-%{version}.tar.xz
Patch0:         ecasound.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  ruby
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(audiofile)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(liboil-0.3)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(lv2)

%description
Ecasound is a software package designed for multitrack audio
processing. It can be used for simple tasks like audio playback,
recording and format conversions, as well as for multitrack effect
processing, mixing, recording and signal recycling. Ecasound
supports a wide range of audio inputs, outputs and effect
algorithms. Several open-source audio packages, like for instance
ALSA, OSS, mpg123, lame, libaudiofile and MikMod, are directly
supported. One of the advantages of ecasound's chain-based design
is that effects can easily be combined both in series and in
parallel. Oscillators and MIDI-CCs can be used for controlling
effect parameters. Included user-interfaces are ecasound - a
versatile console mode interface, qtecasound - a Qt-based
X-interface and various command-line utils suitable for batch
processing.

%package -n libecasound-devel
Summary:        Library header files for ecasound
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(jack)
Requires:       pkgconfig(sndfile)
Provides:       ecasound-devel = %{version}-%{release}
Obsoletes:      ecasound-devel < %{version}-%{release}

%description -n libecasound-devel
Headers files needed for compiling other programs against ecasound
libraries.

%package -n python-ecasound
Summary:        Python Bindings to the Ecasound Control Interface
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Provides:       pyecasound = %{version}-%{release}
Obsoletes:      pyecasound < %{version}-%{release}

%description -n python-ecasound
Python bindings to the Ecasound control interface.

%package -n ruby-ecasound
Summary:        Ruby Bindings to the Ecasound Control Interface
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       ruby

%description -n ruby-ecasound
Ruby bindings to the Ecasound control interface.

%package doc
Summary:        Documentation to the Ecasound Control Interface
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
User documentation for the Ecasound control interface.

%prep
%autosetup -p1

%build
export PYTHONPATH='%_bindir/python3'
sed -i '1s@^.*@#!%_bindir/python3@' ecatools/ecamonitor examples/*.py
autoreconf -fi
%configure \
    --enable-shared \
    --disable-static \
    --disable-arts \
    --disable-oss \
    --disable-osstrigger \
    --with-pic \
    --enable-sys-readline \
    --enable-liboil \
    --enable-liblo \
    --with-python-modules=%{_libdir}/python%{py3_ver} \
    %nil

%make_build

%install
%make_install ECA_S_RUBY_SITEDIR="%{ruby_sitedir}"

# clean ups
find Documentation -name 'Makefile*' -print -delete
find examples -name 'Makefile*' -o -name 'ecatrimsilence*' -print -delete
rm -fv Documentation/*.1
find %{buildroot} -type f -name "*.la" -delete -print

chmod 644 %{buildroot}%{python3_sitearch}/*.py
chmod 644 %{buildroot}%{ruby_sitedir}/%{name}.rb

%fdupes -s %{buildroot}%{_mandir}

%files
%doc AUTHORS BUGS NEWS README
%license COPYING COPYING.GPL COPYING.LGPL
%doc examples/*.{c,cpp,py}
%{_bindir}/ecasound
%{_bindir}/ecaconvert
%{_bindir}/ecafixdc
%{_bindir}/ecalength
%{_bindir}/ecamonitor
%{_bindir}/ecanormalize
%{_bindir}/ecaplay
%{_bindir}/ecasignalview
%config %{_datadir}/%{name}
%{_mandir}/*/*

%files -n libecasound-devel
%{_includedir}/kvutils
%{_includedir}/libecasound
%{_includedir}/libecasoundc
%{_bindir}/libecasound-config
%{_bindir}/libecasoundc-config
%{_libdir}/*.a

%files -n python-ecasound
%{python3_sitearch}/*.py*

%files -n ruby-ecasound
%{ruby_sitedir}/*

%files doc
%doc Documentation/*

%changelog
* Tue Mar 21 2023 olaf@aepfle.de
- update to 2.9.3
* Thu Jul  9 2020 Fridrich Strba <fridrich.strba@bluewin.ch>
- Build using python3
- Fix lv2 pkg-config require for Tumbleweed
* Sun Dec  8 2019 olaf@aepfle.de
- update to 2.9.2
* Sat Oct  8 2016 joerg.lorenzen@ki.tng.de
- Removed service file because build often fails with 'bad temdir'
  and only sometimes succeeds.
* Sat Sep 27 2014 avvissu@yandex.ru
- update to 2.9.1
- Fix Compilation Error: ecasound.rb': No such file or directory:
  + set ECA_S_RUBY_SITEDIR="%%{ruby_sitedir}" in %%{install}
- Add incorrect-fsf-address.patch
- Fix rpmlint warning: specfile-error -e:1: Use RbConfig instead
  of obsolete and deprecated Config
- Fix rpmlint warning: manual-page-warning:
  + del macro %%doc
- del RPM conditional tests for %%{suse_version} == 1100
* Sun May 22 2011 pascal.bleser@opensuse.org
- update to 2.8.1
* Mon Feb 22 2010 toni@links2linux.de
- update to 2.7.1
- Various bugfixes, including a fix to a bug causing audible glitches
  with old versions of ALSA and certain hardware drivers.
* Tue Oct 27 2009 toni@links2linux.de
- update to 2.7.0
- An initial Open Sound Control (OSC) interface for parameter control has been
  added. New '-chorder' and '-eadb' options and a 'cop-get' interactive mode
  command have been added. Optional build time support has been added for using
  liboil to optimize inner loops, giving a small performance boost to many common
  use-scenarios. Various bugs have been fixed in JACK support, MP3 output, and
  option parsing. There are fixes to build problems in Mac OS X.
* Tue Feb 10 2009 toni@links2linux.de
- update to 2.6.0
* Thu Aug 28 2008 toni@links2linux.de
- update to 2.5.2
* Thu Aug 21 2008 toni@links2linux.de
- update to 2.5.1
* Sun Aug 17 2008 toni@links2linux.de
- update to 2.5.0
* Tue Aug 14 2007 toni@links2linux.de
- update to 2.4.6.1
* Mon Dec 18 2006 toni@links2linux.de
- update to 2.4.5
* Tue Sep 19 2006 toni@links2linux.de
- build for packman
* Sat Jan 28 2006 oc2pus@arcor.de 2.4.4-0.oc2pus.1
- update to 2.4.4
- added subpackage ruby-ecasound
* Fri Nov 18 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.3
- rebuild SuSE-10.0
* Thu Sep  8 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.2
- corrected dependency gpp ==> libgpp
* Tue Aug 23 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.1
- update to 2.4.3
- repackes as tar.bz2
* Fri Aug 12 2005 oc2pus@arcor.de 2.4.2-0.oc2pus.1
- update to 2.4.2
- added packager-tag
* Wed Apr 13 2005 oc2pus@arcor.de 2.4.1-0.oc2pus.1
- update to 2.4.1
- based on SuSE spec-file ecasound-2.3.2
